random

package
v2.8.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 16, 2026 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Overview

Package random provides utilities for generating random strings and numbers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Num

func Num(n int) int

Num generates a random integer between 0 and n-1.

func Seq

func Seq(n int) string

Seq generates a random string of length n containing alphanumeric characters (numbers, lowercase and uppercase letters).

Types

This section is empty.

Jump to